#
# spec file for package python-pytest-examples
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-examples
Version:        0.0.17
Release:        1.1
Summary:        Pytest plugin for testing examples in docstrings and markdown files
License:        MIT
URL:            https://github.com/pydantic/pytest-examples
# sdist without tests
Source:         https://files.pythonhosted.org/packages/source/p/pytest-examples/pytest_examples-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/pydantic/pytest-examples/pull/54 adapt tests to pytest 8.3.4
Patch:          newline.patch
BuildRequires:  %{python_module black}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module ruff}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-black
Requires:       python-pytest
Requires:       python-ruff
BuildArch:      noarch
%python_subpackages

%description
Pytest plugin for testing Python code examples in docstrings and markdown files.

`pytest-examples` can:
* lint code examples using `ruff` and `black`
* run code examples
* run code examples and check print statements are inlined correctly in the code

It can also update code examples in place to format them and insert or update print statements.

%prep
%autosetup -p1 -n pytest_examples-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%{python_sitelib}/pytest_examples
%{python_sitelib}/pytest_examples-%{version}.dist-info

%changelog
* Mon Apr 28 2025 Dirk Müller <dmueller@suse.com>
- update to 0.0.17:
  * Improve logic for finding print statements
  * Ensure `print_callback` runs before formatting print args
- update to 0.0.16:
  * add `include_print` config function
* Fri Jan 17 2025 Markéta Machová <mmachova@suse.com>
- update to 0.0.15
  * Adopt uv
  * support for calling a function/coroutine
  * Fix for single line docstrings
  * Typechecking
  * Allow matching prefix with curly braces
- add newline.patch to adapt tests to pytest 8.3.4
* Sun Aug 18 2024 Dirk Müller <dmueller@suse.com>
- update to 0.0.13:
  * Add new module to `sys.modules` so that namespace ops are
    sound
* Wed Jul  3 2024 Dirk Müller <dmueller@suse.com>
- update to 0.0.12:
  * Pin `ruff` version and prep for v0.0.12 release
- update to 0.0.11:
  * Use `tb_lineno` to point to correct line in traceback
  * Fix deprecation warnings in Python 3.12
  * Include tests in sdist
  * `ruff` now requires the `check` specification
- drop ruff05.patch,  fix-traceback.patch,
  support-python-312.patch, test-ruff-0.1.0.patch: upstream
* Mon Jul  1 2024 Dirk Müller <dmueller@suse.com>
- add ruff05.patch: fix exception with ruff 0.5.0
* Sat Mar  9 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Mar  7 2024 Steve Kowalik <steven.kowalik@suse.com>
- Drop patch suppot-python-312.patch.
- Add patch support-python-312.patch, which is a rename of the previous
  patch.
- Add patch fix-traceback.patch, support traceback changes of
  Python 3.12.
* Wed Jan 24 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch suppot-python-312.patch:
  * Support code changes in Python 3.12+.
* Thu Oct 19 2023 Ondřej Súkup <mimi.vx@gmail.com>
- add test-ruff-0.1.0.patch to fix tests with ruvv-0.1.0
* Mon Oct 16 2023 Ondřej Súkup <mimi.vx@gmail.com>
- initial package
